nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Usb1MiscClr

Struct Usb1MiscClr 

#[repr(transparent)]
pub struct Usb1MiscClr(pub u32);
USB Misc Register

Tuple Fields

0: u32

Implementations

Source

impl Usb1MiscClr

pub const fn hs_use_external_r(&self) -> bool

Use external resistor to generate the current bias for the high speed transmitter

pub const fn set_hs_use_external_r(&mut self, val: bool)

Use external resistor to generate the current bias for the high speed transmitter

pub const fn en_deglitch(&self) -> bool

Enable the deglitching circuit of the USB PLL output.

pub const fn set_en_deglitch(&mut self, val: bool)

Enable the deglitching circuit of the USB PLL output.

pub const fn en_clk_utmi(&self) -> bool

Enables the clk to the UTMI block.

pub const fn set_en_clk_utmi(&mut self, val: bool)

Enables the clk to the UTMI block.