#[repr(transparent)]pub struct Usb2MiscSet(pub u32);Expand description
USB Misc Register
Tuple Fields
0: u32Implementations
Sourceimpl Usb2MiscSet
impl Usb2MiscSet
Sourcepub const fn hs_use_external_r(&self) -> bool
pub const fn hs_use_external_r(&self) -> bool
Use external resistor to generate the current bias for the high speed transmitter
Sourcepub const fn set_hs_use_external_r(&mut self, val: bool)
pub const fn set_hs_use_external_r(&mut self, val: bool)
Use external resistor to generate the current bias for the high speed transmitter
Sourcepub const fn en_deglitch(&self) -> bool
pub const fn en_deglitch(&self) -> bool
Enable the deglitching circuit of the USB PLL output.
Sourcepub const fn set_en_deglitch(&mut self, val: bool)
pub const fn set_en_deglitch(&mut self, val: bool)
Enable the deglitching circuit of the USB PLL output.
Sourcepub const fn en_clk_utmi(&self) -> bool
pub const fn en_clk_utmi(&self) -> bool
Enables the clk to the UTMI block.
Sourcepub const fn set_en_clk_utmi(&mut self, val: bool)
pub const fn set_en_clk_utmi(&mut self, val: bool)
Enables the clk to the UTMI block.